==> seeq-58.0.1.184.3-py3-none-any.whl: seeq/spy/notifications/tests/test_emails_system.py <==
import mock

import pytest
from seeq import spy
from seeq.spy import Status
from seeq.spy._errors import SPyValueError, SPyRuntimeError
from seeq.spy.notifications._emails import EmailRecipient
from seeq.spy.tests import test_common


def setup_module():
    test_common.initialize_sessions()


@pytest.mark.system
def test_send_email():
    with mock.patch('seeq.spy.notifications._emails._call_send_email_api', mock.Mock(return_value=None)):
        test_status1 = Status()
        spy.notifications.send_email('test@seeq.com', 'Hello', '<p>HTML content</p>', status=test_status1)
        assert 'Your message has been sent' in test_status1.message
        assert test_status1.code == Status.SUCCESS

        test_status2 = Status()
        spy.notifications.send_email(
            to=[
                'test@seeq.com',
                EmailRecipient(name='Test Name', email='test.email@seeq.com')
            ],
            cc="some_cc_user@seeq.com",
            bcc=['bcc.recipient@seeq.com', 'another.bcc@seeq.com'],
            subject='Subject',
            content='Email content',
            status=test_status2)
        assert 'Your message has been sent' in test_status2.message
        assert test_status2.code == Status.SUCCESS

        test_status3 = Status()
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content', quiet=True, status=test_status3)
        assert test_status3.code == Status.SUCCESS

    error_reason = "Your message could not be sent."
    with mock.patch('seeq.spy.notifications._emails._call_send_email_api',
                    mock.Mock(side_effect=SPyRuntimeError(error_reason))):
        with pytest.raises(SPyRuntimeError, match=error_reason):
            spy.notifications.send_email(to='test@seeq.com', subject='Subject', content='Content')

        test_status1 = Status()
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content', errors='catalog', status=test_status1)
        assert test_status1.code == Status.FAILURE
        assert error_reason in test_status1.message

        test_status2 = Status()
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content',
                                     errors='catalog', quiet=True, status=test_status2)
        assert test_status2.code == Status.FAILURE

    with pytest.raises(SPyValueError, match='At least one recipient needs to be provided'):
        spy.notifications.send_email(to=[], subject='Subject', content='Content')

    with pytest.raises(SPyValueError, match='A non blank subject must be provided'):
        spy.notifications.send_email(to='test@seeq.com', subject='', content='Content')

    with pytest.raises(SPyValueError, match='A non blank content must be provided'):
        spy.notifications.send_email(to='test@seeq.com', subject='Subject', content='')

==> seeq-58.0.2.184.12-py3-none-any.whl: seeq/spy/notifications/tests/test_emails_system.py <==
import mock

import pytest
from seeq import spy
from seeq.spy import Status
from seeq.spy._errors import SPyValueError, SPyRuntimeError
from seeq.spy.notifications._emails import EmailRecipient
from seeq.spy.tests import test_common


def setup_module():
    test_common.initialize_sessions()


@pytest.mark.system
def test_send_email():
    with mock.patch('seeq.spy.notifications._emails._call_send_email_api', mock.Mock(return_value=None)):
        test_status1 = Status()
        spy.notifications.send_email('test@seeq.com', 'Hello', '<p>HTML content</p>', status=test_status1)
        assert 'Your message has been sent' in test_status1.message
        assert test_status1.code == Status.SUCCESS

        test_status2 = Status()
        spy.notifications.send_email(
            to=[
                'test@seeq.com',
                EmailRecipient(name='Test Name', email='test.email@seeq.com')
            ],
            cc="some_cc_user@seeq.com",
            bcc=['bcc.recipient@seeq.com', 'another.bcc@seeq.com'],
            subject='Subject',
            content='Email content',
            status=test_status2)
        assert 'Your message has been sent' in test_status2.message
        assert test_status2.code == Status.SUCCESS

        test_status3 = Status(quiet=True)
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content', status=test_status3)
        assert test_status3.code == Status.SUCCESS

    error_reason = "Your message could not be sent."
    with mock.patch('seeq.spy.notifications._emails._call_send_email_api',
                    mock.Mock(side_effect=SPyRuntimeError(error_reason))):
        with pytest.raises(SPyRuntimeError, match=error_reason):
            spy.notifications.send_email(to='test@seeq.com', subject='Subject', content='Content')

        test_status1 = Status(errors='catalog')
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content', status=test_status1)
        assert test_status1.code == Status.FAILURE
        assert error_reason in test_status1.message

        test_status2 = Status(quiet=True, errors='catalog')
        spy.notifications.send_email('test@seeq.com', 'Subject', 'Content', status=test_status2)
        assert test_status2.code == Status.FAILURE

    with pytest.raises(SPyValueError, match='At least one recipient needs to be provided'):
        spy.notifications.send_email(to=[], subject='Subject', content='Content')

    with pytest.raises(SPyValueError, match='A non blank subject must be provided'):
        spy.notifications.send_email(to='test@seeq.com', subject='', content='Content')

    with pytest.raises(SPyValueError, match='A non blank content must be provided'):
        spy.notifications.send_email(to='test@seeq.com', subject='Subject', content='')
